@@ -18,7 +18,7 @@ def cffi_version():
 def target_version():
     with codecs.open('lib_pypy/cffi/recompiler.py', encoding='UTF-8') as f:
         for line in f:
-            m = re.match(r'^VERSION = "(0x[0-9A-F]+)"$', line)
+            m = re.match(r'^VERSION_CHAR16CHAR32 = (0x[0-9A-F]+)$', line)
             if m:
                 return int(m.group(1), 16)
     raise Exception('Version not found')
@@ -66,7 +66,7 @@ with codecs.open('debian/pypy-lib.substvars', 'a', encoding='UTF-8') as f:
 with codecs.open('debian/pypy.substvars', 'a', encoding='UTF-8') as f:
     f.write('pypy-abi={}\n'.format(pypy_abi()))
 
-path = 'debian/pypy-lib/usr/share/dh-python/dist/pypy'
+path = 'debian/pypy-lib/usr/share/pypy/dist'
 os.makedirs(path)
 with codecs.open(os.path.join(path, 'pypy-cffi'), 'w', encoding='UTF-8') as f:
     f.write('cffi pypy-cffi-backend-api-min (<= {target}), '
